@@ -127,15 +127,19 @@ def connect(host: IColaboFlowHostData):
 	"""
 	connects to the ColaboFlow service through RabbitMQ broker
 	"""
-	print(f"{host.appNameTextWithContext('connect')} Connecting to the server...")
-	parameters = (
-		pika.ConnectionParameters(
-			host=host.amqpUrl,
-			port=5672,
-			connection_attempts=5,
-			retry_delay=1
-		)
-	)
+
+	print(f'{host.appNameTextWithContext("connect")} Connecting to the server, host.amqpUrl = "{host.amqpUrl}"')
+	# parameters = (
+	# 	pika.ConnectionParameters(
+	# 		host=host.amqpUrl,
+	# 		port=5672,
+	# 		connection_attempts=5,
+	# 		retry_delay=1
+	# 	)
+	# )
+
+	# https://pika.readthedocs.io/en/stable/modules/parameters.html#urlparameters
+	parameters = pika.URLParameters(host.amqpUrl)
 
 	# https://pika.readthedocs.io/en/stable/modules/adapters/blocking.html
 	host.connection = pika.BlockingConnection(parameters)
